@@ -8,15 +8,15 @@
 #define SHELL_Q '\''
 
 #define PARIVERSION "GP/PARI CALCULATOR Version 2.17.1 (released)"
-#define PARIINFO "amd64 running linux (x86-64/GMP-%s kernel) 64-bit version"
+#define PARIINFO "amd64 running linux (x86-64 kernel) 64-bit version"
 #define PARI_VERSION_CODE 135425
 #define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 #define PARI_VERSION_SHIFT 8
 #define PARI_VCSVERSION ""
-#define PARI_MT_ENGINE "single"
+#define PARI_MT_ENGINE "pthread"
 
 #define PARI_DOUBLE_FORMAT -
-#define GCC_VERSION "gcc version 14.2.1 20241221 (Gentoo 14.2.1_p20241221 p7)"
+#define GCC_VERSION "gcc version 14.3.1 20250801 (Gentoo 14.3.1_p20250801 p4)"
 #define ASMINLINE
 
 /*  Location of GNU gzip program (enables reading of .Z and .gz files). */
@@ -26,7 +26,7 @@
 
 #define GP_MIME_OPEN "xdg-open"
 
-#define READLINE "8.2"
+#define READLINE "8.3"
 #define LONG_IS_64BIT
 #define HAS_SSE2
 #define HAS_EXP2
@@ -48,4 +48,5 @@
 #define HAS_STRFTIME
 #define HAS_STAT
 #define HAS_MMAP
+#define ENABLE_TLS
 #endif
